@@ -10,9 +10,9 @@ use Carp;
 
 use feature qw(say);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
-has 'sites' => sub { [qw(Hitbtc BtcChina CoinSetter LakeBtc)] };
+has 'sites' => sub { [qw(Hitbtc BtcChina CoinSetter LakeBtc BitStamp)] };
 has 'output' => sub {
     sub { shift; say join " ", @_ }
 };
@@ -20,7 +20,7 @@ has 'output' => sub {
 sub new {
     my $class = shift;
     my $self  = $class->SUPER::new(@_);
-    $self->on( 'output', $self->output );
+    $self->on('output', $self->output);
     return $self;
 }
 
@@ -29,12 +29,12 @@ sub run {
 
     my @sites;
 
-    for my $site_class ( @{ $self->sites } ) {
+    for my $site_class (@{$self->sites}) {
         $site_class = 'Finance::Bitcoin::Feed::Site::' . $site_class;
         eval { require_module($site_class) }
-          || croak("No such module $site_class");
+            || croak("No such module $site_class");
         my $site = $site_class->new;
-        $site->on( 'output', sub { shift, $self->emit( 'output', @_ ) } );
+        $site->on('output', sub { shift, $self->emit('output', @_) });
         $site->go;
         push @sites, $site;
     }
@@ -57,7 +57,7 @@ Finance::Bitcoin::Feed - Collect bitcoin real-time price from many sites' stream
     #default output is to print to the stdout
     Finance::Bitcoin::Feed->new->run();
     # will print output to the stdout:
-    # COINSETTER BTCUSD 123.00
+    # BITSTAMP BTCUSD 123.00
     
 
     #or custom your stdout
@@ -115,11 +115,12 @@ This method have two arguments by which you can costumize the behavior of the fe
 
 =head3 sites
 
-which sites you want to connect. It is in fact the array reference of  module names of Finance::Bitcoin::Feed::Site::*. Now it have 4 modules:
+which sites you want to connect. It is in fact the array reference of  module names of Finance::Bitcoin::Feed::Site::*. Now there are the following sites:
 Hitbtc
 BtcChina
 CoinSetter
 LakeBtc
+BitStamp
 
 You can also put your own site module under this namespace and added here.
 
@@ -184,6 +185,8 @@ And these modules use L<Mojo::UserAgent>, you can also open the MOJO_USERAGENT_D
 
 L<Mojo::EventEmitter>
 
+L<Finance::Bitcoin::Feed::Site::BitStamp>
+
 L<Finance::Bitcoin::Feed::Site::Hitbtc>
 
 L<Finance::Bitcoin::Feed::Site::BtcChina>
@@ -192,6 +195,8 @@ L<Finance::Bitcoin::Feed::Site::CoinSetter>
 
 L<Finance::Bitcoin::Feed::Site::LakeBtc>
 
+L<Finance::Bitcoin::Feed::Site::BitStamp>
+
 =head1 AUTHOR
 
 Chylli  C<< <chylli@binary.com> >>
