@@ -3,7 +3,7 @@ use strict;
 use Mojo::Base 'Finance::Bitcoin::Feed::Site';
 use Mojo::UserAgent;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 has ws_url => 'wss://websocket.btcchina.com/socket.io/?transport=websocket';
 has 'ua';
@@ -13,13 +13,13 @@ sub go {
     my $self = shift;
     $self->SUPER::go;
 
-    $self->ua( Mojo::UserAgent->new() );
-    $self->debug( 'connecting...', $self->ws_url );
+    $self->ua(Mojo::UserAgent->new());
+    $self->debug('connecting...', $self->ws_url);
     $self->ua->websocket(
         $self->ws_url => sub {
-            my ( $ua, $tx ) = @_;
+            my ($ua, $tx) = @_;
             $self->debug('connected!');
-            unless ( $tx->is_websocket ) {
+            unless ($tx->is_websocket) {
                 $self->error("Site BtcChina WebSocket handshake failed!");
 
                 # set timeout;
@@ -29,13 +29,11 @@ sub go {
 
             bless $tx, 'Mojo::Transaction::WebSocket::ForBtcChina';
             $tx->configure($self);
-        }
-    );
+        });
 
 }
 
-package
-	Mojo::Transaction::WebSocket::ForBtcChina;    # hidden from PAUSE
+package Mojo::Transaction::WebSocket::ForBtcChina;    # hidden from PAUSE
 
 use JSON;
 use Mojo::Base 'Mojo::Transaction::WebSocket';
@@ -51,106 +49,98 @@ sub configure {
     my $self  = shift;
     my $owner = shift;
     $self->owner($owner);
-    weaken( $self->{owner} );
+    weaken($self->{owner});
 
     # call parse when receive text event
     $self->on(
         text => sub {
-            my ( $self, $message ) = @_;
+            my ($self, $message) = @_;
             $self->parse($message);
-        }
-    );
+        });
 
     ################################################
     # setup events
     $self->on(
         subscribe => sub {
-            my ( $self, $channel ) = @_;
+            my ($self, $channel) = @_;
             $self->on(
                 'setup',
                 sub {
-                    $self->send( { text => qq(42["subscribe","$channel"]) } );
-                }
-            );
-        }
-    );
-    $self->emit( 'subscribe', 'marketdata_cnybtc' );
-    $self->emit( 'subscribe', 'marketdata_cnyltc' );
-    $self->emit( 'subscribe', 'marketdata_btcltc' );
+                    $self->send({text => qq(42["subscribe","$channel"])});
+                });
+        });
+    $self->emit('subscribe', 'marketdata_cnybtc');
+    $self->emit('subscribe', 'marketdata_cnyltc');
+    $self->emit('subscribe', 'marketdata_btcltc');
 
     #receive trade vent
     $self->on(
         trade => sub {
-            my ( $self, $data ) = @_;
+            my ($self, $data) = @_;
             $self->owner->emit(
                 'data_out',
                 $data->{date} * 1000,    # the unit of timestamp is ms
-                uc( $data->{market} ),
-                $data->{price}
-            );
+                uc($data->{market}),
+                $data->{price});
 
-        }
-    );
+        });
 
     $self->on(
         'ping',
         sub {
-            $self->send( { text => '2' } );
-        }
-    );
+            $self->send({text => '2'});
+        });
 
     # ping ping!
     my $timer = AnyEvent->timer(
         after    => 10,
         interval => 1,
         cb       => sub {
-            if ( time() - $self->last_ping_at > $self->ping_interval / 1000 ) {
+            if (time() - $self->last_ping_at > $self->ping_interval / 1000) {
                 $self->emit('ping');
-                $self->last_ping_at( time() );
+                $self->last_ping_at(time());
             }
-        }
-    );
+        });
     $self->timer($timer);
 
 }
 
 #socket.io v2.2.2
 sub parse {
-    my ( $self, $data ) = @_;
-    $self->owner->last_activity_at( time() );
+    my ($self, $data) = @_;
+    $self->owner->last_activity_at(time());
     return unless $data =~ /^\d+/;
-    my ( $code, $body ) = $data =~ /^(\d+)(.*)$/;
+    my ($code, $body) = $data =~ /^(\d+)(.*)$/;
 
     # connect, setup
-    if ( $code == 0 ) {
+    if ($code == 0) {
         my $json_data = decode_json($body);
 
         #session_id useless ?
 
-        $self->ping_interval( $json_data->{pingInterval} )
-          if $json_data->{pingInterval};
-        $self->ping_timeout( $json_data->{pingTimeout} )
-          if $json_data->{pingTimeout};
-        $self->last_pong_at( time() );
-        $self->last_ping_at( time() );
+        $self->ping_interval($json_data->{pingInterval})
+            if $json_data->{pingInterval};
+        $self->ping_timeout($json_data->{pingTimeout})
+            if $json_data->{pingTimeout};
+        $self->last_pong_at(time());
+        $self->last_ping_at(time());
         $self->emit('setup');
     }
 
     # pong
-    elsif ( $code == 3 ) {
-        $self->last_pong_at( time() );
+    elsif ($code == 3) {
+        $self->last_pong_at(time());
     }
 
     #disconnect ? reconnect!
-    elsif ( $code == 41 ) {
+    elsif ($code == 41) {
         $self->owner->debug('disconnected by server');
 
         #set timeout
         $self->owner->set_timeout();
-    }
-    elsif ( $code == 42 ) {
+    } elsif ($code == 42) {
         my $json_data = decode_json($body);
-        $self->emit( $json_data->[0], $json_data->[1] );
+        $self->emit($json_data->[0], $json_data->[1]);
     }
 
 }
